summaryrefslogtreecommitdiffstats
path: root/build2/test/script/script.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'build2/test/script/script.hxx')
-rw-r--r--build2/test/script/script.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/build2/test/script/script.hxx b/build2/test/script/script.hxx
index 479001b4..4da9d977 100644
--- a/build2/test/script/script.hxx
+++ b/build2/test/script/script.hxx
@@ -536,8 +536,9 @@ namespace build2
script& operator= (const script&) = delete;
public:
- const target& test_target; // Target we are testing.
- const testscript& script_target; // Target of the testscript file.
+ const target& test_target; // Target we are testing.
+ const build2::scope& target_scope; // Base scope of test target.
+ const testscript& script_target; // Target of the testscript file.
// Pre-parse data.
//